From 9b69daad951f3a508fe2a92464e0ebc5e3a5643d Mon Sep 17 00:00:00 2001
From: Grant Rettke <gcr@wisdomandwonder.com>
Date: Wed, 4 Jan 2017 15:32:02 -0600
Subject: [PATCH] ox-koma-letter.el: Add support for fromurl variable

* contrib/lisp/ox-koma-letter.el (org-koma-letter-url, org-koma-letter-use-url, org-koma-letter--build-settings): Add support for fromurl variable

Copied email variable code, pasted it and changed references from email to url.

Tested "url" with "#+URL: url" and "use-url" using "#+OPTIONS url:[nil|t]".

TINYCHANGE
---
 contrib/lisp/ox-koma-letter.el | 24 ++++++++++++++++++++++++
 1 file changed, 24 insertions(+)

diff --git a/contrib/lisp/ox-koma-letter.el b/contrib/lisp/ox-koma-letter.el
index 801ab7dad..806fa038b 100644
--- a/contrib/lisp/ox-koma-letter.el
+++ b/contrib/lisp/ox-koma-letter.el
@@ -58,6 +58,7 @@
 ;;   - foldmarks (see `org-koma-letter-use-foldmarks')
 ;;   - phone (see `org-koma-letter-use-phone')
 ;;   - email (see `org-koma-letter-use-email')
+;;   - url (see `org-koma-letter-use-url')
 ;;   - place (see `org-koma-letter-use-place')
 ;;   - location (see `org-koma-letter-use-location')
 ;;   - subject, a list of format options
@@ -171,6 +172,12 @@ This option can also be set with the EMAIL keyword."
 		(function)
 		(const :tag "Do not export email" nil)))
 
+(defcustom org-koma-letter-url ""
+  "Sender's URL, as a string.
+This option can also be set with the URL keyword."
+  :group 'org-export-koma-letter
+  :type 'string)
+
 (defcustom org-koma-letter-from-address ""
   "Sender's address, as a string.
 This option can also be set with one or more FROM_ADDRESS
@@ -369,6 +376,13 @@ This option can also be set with the OPTIONS keyword, e.g.:
   :group 'org-export-koma-letter
   :type 'boolean)
 
+(defcustom org-koma-letter-use-url nil
+  "Non-nil prints sender's URL.
+This option can also be set with the OPTIONS keyword, e.g.:
+\"url:t\"."
+  :group 'org-export-koma-letter
+  :type 'boolean)
+
 (defcustom org-koma-letter-use-place t
   "Non-nil prints the letter's place next to the date.
 This option can also be set with the OPTIONS keyword, e.g.:
@@ -427,6 +441,7 @@ e.g. \"title-subject:t\"."
     (:from-address "FROM_ADDRESS" nil org-koma-letter-from-address newline)
     (:phone-number "PHONE_NUMBER" nil org-koma-letter-phone-number)
     (:email "EMAIL" nil (org-koma-letter--get-value org-koma-letter-email) t)
+    (:url "URL" nil org-koma-letter-url)
     (:to-address "TO_ADDRESS" nil nil newline)
     (:place "PLACE" nil org-koma-letter-place)
     (:location "LOCATION" nil org-koma-letter-location)
@@ -443,6 +458,7 @@ e.g. \"title-subject:t\"."
 				org-koma-letter-special-tags-after-letter)
     (:with-backaddress nil "backaddress" org-koma-letter-use-backaddress)
     (:with-email nil "email" org-koma-letter-use-email)
+    (:with-url nil "url" org-koma-letter-use-url)
     (:with-foldmarks nil "foldmarks" org-koma-letter-use-foldmarks)
     (:with-phone nil "phone" org-koma-letter-use-phone)
     (:with-place nil "place" org-koma-letter-use-place)
@@ -749,6 +765,14 @@ a communication channel."
      (and (funcall check-scope 'with-email)
           (format "\\KOMAoption{fromemail}{%s}\n"
                   (if (plist-get info :with-email) "true" "false")))
+     ;; URL
+     (let ((url (plist-get info :url)))
+       (and (org-string-nw-p url)
+            (funcall check-scope 'url)
+            (format "\\setkomavar{fromurl}{%s}\n" url)))
+     (and (funcall check-scope 'with-url)
+          (format "\\KOMAoption{fromurl}{%s}\n"
+                  (if (plist-get info :with-url) "true" "false")))
      ;; Phone number.
      (let ((phone-number (plist-get info :phone-number)))
        (and (org-string-nw-p phone-number)
-- 
2.11.0

